@@ -1,7 +1,7 @@
 #!/bin/sh
 echo 'name: network
-version: 2.3.0.5
-id: network-2.3.0.5-8b6868c0e6dbf6adced217440d46f03d
+version: 2.3.1.0
+id: network-2.3.1.0-e56ec3d5abd17b7b386690bf49d424ab
 
 license: BSD3
 copyright:
@@ -9,6 +9,7 @@ maintainer: Johan Tibell <johan.tibell@gmail.com>
 stability:
 homepage: http://github.com/haskell/network
 package-url:
+synopsis: Low-level networking interface
 description: Low-level networking interface
 category: Network
 author:
@@ -19,22 +20,23 @@ exposed-modules: Network Network.BSD Network.Socket
                  Network.Socket.Internal Network.URI
 hidden-modules: Network.Socket.ByteString.IOVec
                 Network.Socket.ByteString.MsgHdr Network.Socket.ByteString.Internal
-import-dirs: /usr/local/lib/ghc/network-2.3.0.5
-library-dirs: /usr/local/lib/ghc/network-2.3.0.5
-hs-libraries: HSnetwork-2.3.0.5
+trusted: False
+import-dirs: /usr/local/lib/ghc/network-2.3.1.0
+library-dirs: /usr/local/lib/ghc/network-2.3.1.0
+hs-libraries: HSnetwork-2.3.1.0
 extra-libraries:
 extra-ghci-libraries:
-include-dirs: /usr/local/lib/ghc/network-2.3.0.5/include
+include-dirs: /usr/local/lib/ghc/network-2.3.1.0/include
 includes: HsNet.h
-depends: base-4.3.1.0-ee15f259a627d341af7c80a17e8b0e66
-         bytestring-0.9.1.10-4e62762ee9b2a5d0cc5bc2fbaaeefd53
-         parsec-3.1.1-bf92fff0e29c344f3b78cfddb556a5b9
-         unix-2.4.2.0-41b8af27cfe8b819176ab06a4cb79133
+depends: base-4.5.1.0-5b1c9d3d412ed227632edae6d2aca151
+         bytestring-0.9.2.1-3c5b69d9d36e3a0179d120b97025ab86
+         parsec-3.1.3-fb970d7908f363dfef34b141200235e6
+         unix-2.5.1.1-c23dadb7ccff9eeb5d1df0bd91909ca9
 hugs-options:
 cc-options:
 ld-options:
 framework-dirs:
 frameworks:
-haddock-interfaces: /usr/local/share/doc/hs-network-2.3.0.5/html/network.haddock
-haddock-html: /usr/local/share/doc/hs-network-2.3.0.5/html
+haddock-interfaces: /usr/local/share/doc/hs-network-2.3.1.0/html/network.haddock
+haddock-html: /usr/local/share/doc/hs-network-2.3.1.0/html
 ' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-conf' "$@"
